firestore_paging_controller library

Classes

FirestorePagingController<ItemType>
Creates a FirestorePagingController that fetches items from Firestore and paginates them to be used with infinite_scroll_pagination views, like PagedListView.
PagedAlignedGridView<PageKeyType, ItemType>
A AlignedGridView with pagination capabilities.
PagedChildBuilderDelegate<ItemType>
Supplies builders for the visual components of paged views.
PagedGridView<PageKeyType, ItemType>
A GridView with pagination capabilities.
PagedLayoutBuilder<PageKeyType, ItemType>
Facilitates creating infinitely scrolled paged layouts.
PagedListView<PageKeyType, ItemType>
A ListView with pagination capabilities.
PagedMasonryGridView<PageKeyType, ItemType>
A MasonryGridView with pagination capabilities.
PagedPageView<PageKeyType, ItemType>
Paged PageView with progress and error indicators displayed as the last item.
PagedSliverAlignedGrid<PageKeyType, ItemType>
A SliverAlignedGrid with pagination capabilities.
PagedSliverGrid<PageKeyType, ItemType>
Paged SliverGrid with progress and error indicators displayed as the last item.
PagedSliverList<PageKeyType, ItemType>
A SliverList with pagination capabilities.
PagedSliverMasonryGrid<PageKeyType, ItemType>
A SliverMasonryGrid with pagination capabilities.
PagingController<PageKeyType, ItemType>
A controller for a paged widget.
PagingState<PageKeyType, ItemType>
The current item's list, error, and next page key state for a paginated widget.

Enums

PagedLayoutProtocol
The Flutter layout protocols supported by PagedLayoutBuilder.
PagingStatus
All possible status for a pagination.

Typedefs

CompletedListingBuilder = Widget Function(BuildContext context, IndexedWidgetBuilder itemWidgetBuilder, int itemCount, WidgetBuilder? noMoreItemsIndicatorBuilder)
ErrorListingBuilder = Widget Function(BuildContext context, IndexedWidgetBuilder itemWidgetBuilder, int itemCount, WidgetBuilder newPageErrorIndicatorBuilder)
FromMap<T> = T Function(StringMap)
ItemWidgetBuilder<ItemType> = Widget Function(BuildContext context, ItemType item, int index)
LoadingListingBuilder = Widget Function(BuildContext context, IndexedWidgetBuilder itemWidgetBuilder, int itemCount, WidgetBuilder newPageProgressIndicatorBuilder)
PageRequestListener<PageKeyType> = void Function(PageKeyType pageKey)
PagingStatusListener = void Function(PagingStatus status)
SliverSimpleGridDelegateBuilder = SliverSimpleGridDelegate Function(int childCount)
StringMap = Map<String, dynamic>